import com.github.ajalt.clikt.core.CliktCommand
import com.github.ajalt.clikt.parameters.options.option
import com.github.ajalt.clikt.parameters.options.required
import com.github.ajalt.clikt.parameters.types.path
import day1.Day1
import day2.Day2
import java.nio.file.Path
import kotlin.RuntimeException

class CliParser: CliktCommand() {
    private val dayToRun: String by option(help = "Day to Run. Can be either an int (1) or a String (Day1)").required()
    private val partToRun: String by option(help = "Part to run. Usually 1 or 2").required()
    private val inputFile: Path by option().path().required()

    override fun run() {
        when(val it = "${dayToRun.replace("Day", "")}.${partToRun}") {
            "1.1" -> println(Day1().runPart1(inputFile))
            "1.2" -> println(Day1().runPart2(inputFile))
            "2.1" -> println(Day2().runPart1(inputFile))
            "2.2" -> println(Day2().runPart2(inputFile))
            else -> throw RuntimeException("Day or part (${it}) not implementation yet")
        }
    }
}

fun main(args: Array<String>) {
    CliParser().main(args)
}